import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.nio.file.Files;
import java.nio.file.Paths;


public class ExampleJavaJson {

	public static void main(String[] args) throws Exception {
		String baseurl = "http://optimizer2.routesavvy.com/RSAPI.svc/";
		boolean POST = true;
		
		try {
			if(args.length != 2) {
				System.out.println("usage: <input json request file> <output json result file>");
				System.out.println("Press any key to exit.");
                System.in.read();
				return;
			}
			String inFilePath = args[0];
            String outFilePath = args[1];
			
			String request = new String(Files.readAllBytes(Paths.get(inFilePath)));
			//remove line breaks from str
			request = request.replaceAll("\t", "");
			request = request.replaceAll("\\r|\\n", "");

			System.out.println(request);
	        StringBuilder response = new StringBuilder();
	        String line = null;
	        
			if(POST) {
				URL url = new URL(baseurl + "POSTOptimize");
			    HttpURLConnection connection = (HttpURLConnection) url.openConnection();
			    connection.setConnectTimeout(30000);//30 secs
			    connection.setReadTimeout(30000);//30 secs

			    connection.setRequestMethod("POST");
			    connection.setDoOutput(true);
			    connection.setRequestProperty("Content-Type", "application/json");

			    OutputStreamWriter out = new OutputStreamWriter(connection.getOutputStream());  
			    out.write(request);
			    out.flush();
			    out.close();

			    int responseCode = connection.getResponseCode();
			    if (responseCode == HttpURLConnection.HTTP_OK) {
			        BufferedReader reader = new BufferedReader(new InputStreamReader(connection.getInputStream()));

			        while ((line = reader.readLine()) != null) {
			            response.append(line);
			        }
			        reader.close();
			    }
			    System.out.println();
			    System.out.println(response.toString());

			    connection.disconnect();

			}
			else { //GETOptimize
				String url = "http://optimizer2.routesavvy.com/RSAPI.svc/GETOptimize?query=";

				URL obj = new URL(url + URLEncoder.encode(request, "UTF-8"));
				HttpURLConnection con = (HttpURLConnection) obj.openConnection();
				con.setRequestMethod("GET");

				int responseCode = con.getResponseCode();
				System.out.println("Response Code : " + responseCode);
				
				if(responseCode == 200) {
					BufferedReader in = new BufferedReader(new InputStreamReader(con.getInputStream()));
					String inputLine;
	
					while ((inputLine = in.readLine()) != null) {
						response.append(inputLine);
					}
					in.close();
	
					//print result
					System.out.println(response.toString());
					

				}
			}
		    BufferedWriter writer = null;
	        try {

	            File jsonFile = new File(outFilePath);
	            writer = new BufferedWriter(new FileWriter(jsonFile));
	            writer.write(response.toString());
	        } catch (Exception e) {
	            e.printStackTrace();
	        } finally {
	            try {
	                writer.close();
	            } catch (Exception e) {
	            }
	        }
           
		} catch(IOException ex) {
			ex.printStackTrace();
		}
		
	}

}
